/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  backend-db31.h header file for backend-db31.c
  markus@mhoenicka.de 6-21-00
  $Id: backend-db31.h,v 1.4.2.1 2005/04/15 22:45:05 mhoenicka Exp $

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, see <http://www.gnu.org/licenses/>

  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

int prepare_render_db31(struct renderinfo* ptr_rendinfo);
int finish_render_db31(struct renderinfo* ptr_rendinfo);
int render_db31(struct renderinfo* ptr_rendinfo);
int prepare_render_db50(struct renderinfo* ptr_rendinfo);
int finish_render_db50(struct renderinfo* ptr_rendinfo);
int render_db50(struct renderinfo* ptr_rendinfo);



